use std::collections::HashMap;
use std::fs;
use tera::Tera;
use serde::Deserialize;
#[derive(Deserialize, serde::Serialize)]
struct ReadmeConfig {
    header: Image,
    project: Project
}

#[derive(Deserialize, serde::Serialize)]
struct Project {
    name: String,
    summary: String,
    description: String,
    language: String,
    licence: String,
    lifecycle: String,
    badges: Vec<Image>,
}

#[derive(Deserialize, serde::Serialize)]
struct Image {
    alt: String,
    href: String,
    src: String,
}

#[derive(Deserialize)]
struct Language {
    color: String
}


fn main() {
    let mut readme_template = Tera::new("templates/**/*").unwrap();
    readme_template.add_template_file("templates/readme_templ.j2", Option::from("readme")).unwrap();
    let mut context = tera::Context::new();

    let language_colours = include_str!("languages.toml");
    let language_colours_config: HashMap<String, Language> = toml::from_str(language_colours).unwrap();
   // println!("{:?}", colours_config);

    let toml_filename = "README.toml";
    let contents: String = fs::read_to_string(toml_filename).unwrap();
    let readme_config: ReadmeConfig = toml::from_str(&contents).expect("Failed to parse readme.toml");
    
    
    let project_language = &readme_config.project.language;
    let project_language_colour = language_colours_config.get(project_language).unwrap();
    
    context.insert("config", &readme_config);
    
    let rendered = readme_template.render("readme", &context).unwrap();
    //println!("{}", rendered);

}
